This directory contains 6 modules copied from  https://github.com/jorvis/biocode
We first used the code from pypi but faced the issue that it was not on bioconda
After a few trials, we realised that dependencies were not maintained so it was not
possible to put biocode on bioconda. Hence, we copied the relevant code to perform
the conversion from genbank to gff here until a better solution can be found.
